@@ -11,11 +11,9 @@ use My::Module::Recommend::All qw{ __all };
 
 my ( $is_5_010, $is_5_012 );
 
-eval {
-    require 5.012;
+if ( $] ge '5.012' ) {
     $is_5_012 = $is_5_010 = 1;
-} or eval {
-    require 5.010;
+} elsif ( $] ge '5.010' ) {
     $is_5_010 = 1;
 };
 
@@ -52,7 +50,25 @@ EOD
       These modules are used to format times, and provide full time zone
       support. If they are not installed, POSIX::strftime() will be
       used, and you may find that you can not display correct local
-      times for zones other than your system's default zone or GMT.
+      times for zones other than your system's default zone or GMT. They
+      will also be used (if available) by the ISO8601 time parser
+      because they go farther into the past than Time::Local does.
+EOD
+
+    # CAVEAT:
+    #
+    # Unfortunately as things currently stand, the version needs to be
+    # maintained three places:
+    # - lib/Astro/App/Satpass2/Utils.pm
+    # - inc/My/Module/Recommend.pm
+    # - inc/My/Module/Test/App.pm
+    # These all need to stay the same. Sigh.
+
+    __any( 'DateTime::Calendar::Christian=0.06'	=> <<'EOD' ),
+      This module is used to parse (maybe) and format dates that might
+      be either Julian or Gregorian. Currently the only parser that has
+      this capability is ISO8601. If historical dates in the proleptic
+      Gregorian calendar are fine with you, you do not need this module.
 EOD
     __any( 'Geo::Coder::OSM'		=> <<'EOD' ),
       This module is required for the Astro::App::Satpass2 geocode()
@@ -93,6 +109,10 @@ EOD
       is available.
 EOD
     ),
+    __any( 'Time::HiRes'		=> <<'EOD' ),
+      This module is required only for the time() command/method. If
+      you do not plan to use this method you do not need this module.
+EOD
 );
 
 sub make_optional_modules_tests {
