@@ -14,7 +14,7 @@ use Getopt::Long 2.33;
 use Scalar::Util 1.26 qw{ blessed looks_like_number };
 use Text::ParseWords ();
 
-our $VERSION = '0.031_02';
+our $VERSION = '0.031_03';
 
 our @EXPORT_OK = qw{
     __arguments
@@ -661,6 +661,10 @@ C<< join ' ', ... >>. Otherwise they are simply returned.
 
  my $epoch = time_gm( $yr, $mon, $day, $hr, $min, $sec );
 
+B<Note:> Despite its name, this subroutine is B<private> to the
+C<Astro-App-Satpass2> package, and may well be moved upstream to
+L<Astro::Coord::ECI::Utils|Astro::Coord::ECI::Utils>.
+
 This exportable subroutine is a wrapper for either
 C<Time::y2038::timegm()> (if that module is installed) or
 C<Time::Local::timegm()> (if not.)
@@ -675,6 +679,10 @@ greater than 999 as Gregorian years.
 
  my $epoch = time_local( $yr, $mon, $day, $hr, $min, $sec );
 
+B<Note:> Despite its name, this subroutine is B<private> to the
+C<Astro-App-Satpass2> package, and may well be moved upstream to
+L<Astro::Coord::ECI::Utils|Astro::Coord::ECI::Utils>.
+
 This exportable subroutine is a wrapper for either
 C<Time::y2038::timelocal()> (if that module is installed) or
 C<Time::Local::timelocal()> (if not.)
